@@ -86,22 +86,11 @@ corx <-
 
     if(methods::is(data, "matrix")) data <- data.frame(data, check.names = FALSE)
 
-    x <- tidyselect::vars_select(colnames(data), {{x}}, .strict = F)
-    y <- tidyselect::vars_select(colnames(data), {{y}}, .strict = F)
-    z <- tidyselect::vars_select(colnames(data), {{z}}, .strict = F)
+    x <- tidyselect::vars_select(colnames(data), {{x}}, .strict = TRUE)
+    y <- tidyselect::vars_select(colnames(data), {{y}}, .strict = TRUE)
+    z <- tidyselect::vars_select(colnames(data), {{z}}, .strict = TRUE)
 
     # allow rename within select
-    rename_if_needed <- function(data, x) {
-      rename_vars <- x[names(x) != x]
-      for (i in seq_along(rename_vars)) {
-        if (names(x)[i] != x[i]) {
-          colnames(data)[colnames(data) == x[i]] <- names(rename_vars[rename_vars == x[i]])
-        }
-      }
-
-      data
-    }
-
     data <- rename_if_needed(data, x)
     data <- rename_if_needed(data, y)
     data <- rename_if_needed(data, z)
@@ -109,36 +98,6 @@ corx <-
     if(length(x) > 0) x <- names(x)
     if(length(y) > 0) y <- names(y)
     if(length(z) > 0) z <- names(z)
-    # --
-
-    x <- check_for_vec(x, call$x, parent_env)
-    y <- check_for_vec(y, call$y, parent_env)
-    z <- check_for_vec(z, call$z, parent_env)
-
-    get_input <- function(x){ # grab plain text input
-      x = as.character(x)
-      if(length(x)>1) x <- x[-1]
-      x
-    }
-    x_orig <- get_input(call$x)
-    y_orig <- get_input(call$y)
-    z_orig <- get_input(call$z)
-
-
-
-    to_check <- c()
-
-    if(length(x) == 0 & length(x_orig) > 0){ # did the user try to get a var and failed
-      to_check <- c(to_check, x_orig) # check what the deal is
-    }
-    if(length(y) == 0 & length(y_orig) > 0){
-      to_check <- c(to_check, y_orig)
-    }
-    if(length(z) == 0 & length(z_orig) > 0){
-      to_check <- c(to_check, z_orig)
-    }
-
-    check_names(data, unique(to_check))
 
     if(length(x) == 0){
       x <- names(data)
@@ -157,8 +116,6 @@ corx <-
       y <- y[!y %in% z]
     }
 
-
-
     if(length(x) == 0 | length(y) == 0) stop("Can't partial out the entirety of x or y")
 
     # check classes are appropriate
@@ -458,44 +415,6 @@ plot.corx <- function(x, ...){
   do.call(ggcorrplot::ggcorrplot, elip)
 }
 
-check_names <- function (x, vars) {
-  vars <- unique(vars)
-
-  if(!is.matrix(x)){
-    name_data <- names(x)
-  }else{
-    name_data <- colnames(x)
-  }
-
-  error_names <- vars[!vars %in% name_data]
-
-  find_name <- function(n) {
-    prob_name <- name_data[agrep(n, name_data)]
-
-    if (length(prob_name) == 1) {
-      return(glue::glue("'{n}' ['{prob_name}'?]"))
-    } else{
-      return(n)
-    }
-  }
-
-  error_names <- unlist(lapply(error_names, find_name))
-
-  if(length(error_names) > 1){
-    stem <- "names"
-  }else{
-    stem <- "name"
-  }
-
-  mess1 <- glue::glue(
-    "{length(error_names)} {stem} could not be found: {paste(error_names, collapse = ', ')}."
-  )
-
-  if (length(error_names) > 0) {
-    stop(mess1, call. = F)
-  }
-}
-
 #' @export
 summary.corx <- function(object,... , digits, quantile.type){
   name_mat <- colnames(object$apa)
@@ -557,22 +476,19 @@ star_matrix <- function(m, stars) {
   s_matrix
 }
 
-#' check_for_vec
+#' rename if needed
 #'
-#' convert vectors of names to character vectors
-#' @param names names to check
-#' @param sym names from call
-#' @param env environment to search
+#' Renames columns
+#' @param data data object
+#' @param x a character vector. If named, columns will be renamed
 
- check_for_vec <- function(names, sym, env){
-
-      if(length(names) == 0 & !is.null(sym)){
-
-        if(as.character(sym) %in% ls(envir = env)){
-          names <- get(as.character(sym))
+  rename_if_needed <- function(data, x) {
+      rename_vars <- x[names(x) != x]
+      for (i in seq_along(rename_vars)) {
+        if (names(x)[i] != x[i]) {
+          colnames(data)[colnames(data) == x[i]] <- names(rename_vars[rename_vars == x[i]])
         }
-
       }
 
-     names
-}
+      data
+    }
